package com.mortals.xhx.module.customer.service.impl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.util.DateUtils;
import com.mortals.framework.util.SecurityUtil;
import com.mortals.framework.util.StringUtils;
import com.mortals.xhx.module.customer.model.CustomerEntityExt;
import com.mortals.xhx.module.customer.model.CustomerQuery;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.customer.dao.CustomerDao;
import com.mortals.xhx.module.customer.model.CustomerEntity;
import com.mortals.xhx.module.customer.service.CustomerService;

import java.util.ArrayList;
import java.util.List;

/**
* CustomerService
* 客户管理 service实现
*
* @author zxfei
* @date 2022-06-08
*/
@Service("customerService")
public class CustomerServiceImpl extends AbstractCRUDServiceImpl<CustomerDao, CustomerEntity, Long> implements CustomerService {

    @Override
    protected void saveBefore(CustomerEntity entity, Context context) throws AppException {
        this.validData(entity, context);
        if (StringUtils.isNotEmpty(entity.getPassword())) {
            try {
                entity.setPassword(SecurityUtil.md5DoubleEncoding(entity.getPassword()));
            } catch (Exception e) {
                throw new AppException("密码转换异常");
            }
        } else {
            entity.setPassword(null);
        }
    }

    @Override
    protected CustomerEntity findBefore(CustomerEntity entity, PageInfo pageInfo, Context context) throws AppException {
        CustomerQuery query = new CustomerQuery();
        BeanUtils.copyProperties(entity,query);
        if(StringUtils.isNotEmpty(entity.getQuery())){
            StringBuffer condition = new StringBuffer("%");
            condition.append(entity.getQuery()).append("%");
            CustomerQuery condition1 = new CustomerQuery();
            CustomerQuery condition2 = new CustomerQuery();
            CustomerQuery condition3 = new CustomerQuery();
            condition1.setContactTelphone(condition.toString());
            condition2.setLoginName(condition.toString());
            condition3.setCustName(condition.toString());
            List<CustomerQuery> orConditionList = new ArrayList<>();
            orConditionList.add(condition1);
            orConditionList.add(condition2);
            orConditionList.add(condition3);
            query.setOrConditionList(orConditionList);
        }
        return query;
    }

    @Override
    public Result<CustomerEntityExt> findExt(CustomerEntity params, PageInfo pageInfo, Context context) throws AppException {
        CustomerEntity query = this.findBefore(params, pageInfo, context);
        Result<CustomerEntityExt> result = getDao().getListExt(query,pageInfo);
        List<CustomerEntityExt> list = result.getList();
        if(CollectionUtils.isNotEmpty(list)){
            list.stream().forEach(item->{
                item.setCreateTimeStr(DateUtils.getDateTime(item.getCreateTime(),DateUtils.P_yyyy_MM_dd_HH_mm_ss));
            });
        }
        return result;
    }

    @Override
    public CustomerEntity doLogin(String loginName, String password, String loginIp) throws AppException {
        CustomerEntity user = this.findByLoginName(loginName);
        if (user == null || !user.getLoginName().equals(loginName)) {
            throw new AppException("用户名不存在！");
        }
        try {
            if (!user.getPassword().equals(SecurityUtil.md5DoubleEncoding(password))) {
                throw new AppException("登录密码错误！");
            }
        } catch (Exception e) {
            throw new AppException("密码验认出错！", e);
        }

        return user;
    }

    private CustomerEntity findByLoginName(String loginName) {
        CustomerEntity params = new CustomerEntity();
        params.setLoginName(loginName);
        return this.selectOne(params);
    }
}