package com.mortals.xhx.module.customer.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.common.IBaseEnum;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.util.StringUtils;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.common.code.CustomerSatusEnum;
import com.mortals.xhx.common.code.CustomerSrcEnum;
import com.mortals.xhx.common.code.MemberLevelEnum;
import com.mortals.xhx.common.code.SexEnum;
import com.mortals.xhx.module.customer.model.CustomerEntity;
import com.mortals.xhx.module.customer.model.CustomerQuery;
import com.mortals.xhx.module.customer.service.CustomerService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;
/**
*
* 客户管理
*
* @author zxfei
* @date 2022-06-08
*/
@RestController
@RequestMapping("customer")
public class CustomerController extends BaseCRUDJsonBodyMappingController<CustomerService,CustomerEntity,Long> {

    public CustomerController(){
        super.setModuleDesc( "客户管理");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model,"memberLevel", IBaseEnum.getEnumMap(MemberLevelEnum.class));
        this.addDict(model,"sex", IBaseEnum.getEnumMap(SexEnum.class));
        this.addDict(model,"status", IBaseEnum.getEnumMap(CustomerSatusEnum.class));
        this.addDict(model,"customerSrc", IBaseEnum.getEnumMap(CustomerSrcEnum.class));
        super.init(model, context);
    }

    @Override
    public String list(@RequestBody(required = false) CustomerEntity query) {
        Map<String, Object> model = new HashMap();
        JSONObject ret = new JSONObject();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();

        int code;
        try {
            PageInfo pageInfo = this.buildPageInfo(query);
            this.doListBefore(query, model, context);
            Result result = this.getService().findExt(query, pageInfo, context);
            model.put("data", result.getList());
            model.put("pageInfo", result.getPageInfo());
            this.parsePageInfo(model, result.getPageInfo());
            code = this.doListAfter(query, model, context);
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("dict", model.remove("dict"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    @GetMapping({"status/enable"})
    public String enableStatus(Long[] id) {
        Context context = this.getContext();
        if (id == null) {
            return this.createFailJsonResp("请至少选择一条记录");
        } else {
            Map<String, Object> model = new HashMap();
            int code = 1;
            String busiDesc = "启用客户" + this.getModuleDesc();

            try {
                CustomerEntity entity = new CustomerEntity();
                entity.setStatus(CustomerSatusEnum.NORMAL.getValue());
                CustomerQuery condition = new CustomerQuery();
                List<Long> idList = new ArrayList<>(id.length);
                Collections.addAll(idList,id);
                condition.setIdList(idList);
                int iRet = this.service.updateBatch(entity,condition,context);
                model.put("message_info", this.getModuleDesc() + "启用成功!启用条数:" + iRet);
                this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + StringUtils.converArray2Str(id) + "]");
            } catch (Exception var7) {
                code = -1;
                this.doException(this.request, busiDesc, model, var7);
            }

            JSONObject ret = new JSONObject();
            ret.put("code", Integer.valueOf(code));
            ret.put("msg", model.remove("message_info"));
            ret.put("data", model);
            return ret.toJSONString();
        }
    }

    @GetMapping({"status/disable"})
    public String disableStatus(Long[] id) {
        Context context = this.getContext();
        if (id == null) {
            return this.createFailJsonResp("请至少选择一条记录");
        } else {
            Map<String, Object> model = new HashMap();
            int code = 1;
            String busiDesc = "禁用客户" + this.getModuleDesc();

            try {
                CustomerEntity entity = new CustomerEntity();
                entity.setStatus(CustomerSatusEnum.DISABLE.getValue());
                CustomerQuery condition = new CustomerQuery();
                List<Long> idList = new ArrayList<>(id.length);
                Collections.addAll(idList,id);
                condition.setIdList(idList);
                int iRet = this.service.updateBatch(entity,condition,context);
                model.put("message_info", this.getModuleDesc() + "禁用成功!禁用条数:" + iRet);
                this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + StringUtils.converArray2Str(id) + "]");
            } catch (Exception var7) {
                code = -1;
                this.doException(this.request, busiDesc, model, var7);
            }

            JSONObject ret = new JSONObject();
            ret.put("code", Integer.valueOf(code));
            ret.put("msg", model.remove("message_info"));
            ret.put("data", model);
            return ret.toJSONString();
        }
    }

    @Override
    protected int editAfter(Long id, Map<String, Object> model, CustomerEntity entity, Context context) throws AppException {
        entity.setPassword(null);
        return 1;
    }

    @Override
    protected int viewAfter(Long id, Map<String, Object> model, CustomerEntity entity, Context context) throws AppException {
        entity.setPassword(null);
        return 1;
    }
}