package com.mortals.xhx.module.picture.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.model.ParamEntity;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.base.system.param.web.ParamForm;
import com.mortals.xhx.common.code.PictureTypeEnum;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.module.picture.model.vo.PictureGroupCountVo;
import com.mortals.xhx.module.picture.service.PictureMaterialService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.parameters.P;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("material/group")
public class PictureGroupController extends BaseCRUDJsonBodyMappingController<ParamService, ParamEntity,Long> {

    @Autowired
    private PictureMaterialService pictureMaterialService;

    public PictureGroupController() {
        super.setModuleDesc("素材分组");
    }

    @Override
    protected void saveBefore(ParamEntity entity, Map<String, Object> model, Context context) throws AppException {
        if(StringUtils.isEmpty(entity.getPictureGroupName())){
            throw new AppException("分组名称不能为空");
        }
        if(entity.getId()==null){
            ParamEntity query = new ParamEntity();
            query.setFirstOrganize("PictureMaterial");
            query.setSecondOrganize("pictureGroupId");
            List<ParamEntity> paramEntities = this.service.find(query);
            int max = 0;
            if(paramEntities.isEmpty()){
                max = 1;
            }else {
                ParamEntity maxEntity = paramEntities.stream().max(Comparator.comparing(ParamEntity::getParamKey)).get();
                max = DataUtil.converStr2Int(maxEntity.getParamKey(),paramEntities.size())+1;
            }
            entity.setParamKey(max+"");
            entity.setName("素材分组");
            entity.setFirstOrganize("PictureMaterial");
            entity.setSecondOrganize("pictureGroupId");
        }
        entity.setParamValue(entity.getPictureGroupName());

    }

    @Override
    public String list(@RequestBody ParamEntity entity) {
        Map<String, Object> model = new HashMap();
        JSONObject ret = new JSONObject();
        ret.put("code", -1);
        ret.put("msg", "无法访问");
        ret.put("data", model);
        return ret.toJSONString();
    }

    @PostMapping({"element"})
    public String element(@RequestBody ParamEntity entity) {
        Map<String, Object> model = new HashMap();
        JSONObject ret = new JSONObject();
        String busiDesc = "查询" + this.getModuleDesc();
        int code=1;
        try {
            List<PictureGroupCountVo> list = pictureMaterialService.selectPictureGroupCount(PictureTypeEnum.ELEMENT.getValue());
            model.put("data", list);
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    @PostMapping({"picture"})
    public String picture(@RequestBody ParamEntity entity) {
        Map<String, Object> model = new HashMap();
        JSONObject ret = new JSONObject();
        String busiDesc = "查询" + this.getModuleDesc();
        int code=1;
        try {
            List<PictureGroupCountVo> list = pictureMaterialService.selectPictureGroupCount(PictureTypeEnum.PICTURE.getValue());
            model.put("data", list);
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    @PostMapping({"background"})
    public String background(@RequestBody ParamEntity entity) {
        Map<String, Object> model = new HashMap();
        JSONObject ret = new JSONObject();
        String busiDesc = "查询" + this.getModuleDesc();
        int code=1;
        try {
            List<PictureGroupCountVo> list = pictureMaterialService.selectPictureGroupCount(PictureTypeEnum.BACKGROUND.getValue());
            model.put("data", list);
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }
}
